@@ -19,6 +19,7 @@
 #include <time.h>
 #include <unistd.h>
 #include "timespecops.h"
+#include "ntpfrob.h"
 
 #ifdef HAVE_SYS_TIMEPPS_H
 #include <sys/timepps.h>
@@ -37,8 +38,9 @@
                 }                                                       \
         } while (0)
 
+static void Chew(struct timespec *, struct timespec *, unsigned, unsigned);
 
-void
+static void
 Chew(struct timespec *tsa, struct timespec *tsc, unsigned sa, unsigned sc)
 {
 	struct timespec ts;
@@ -61,7 +63,7 @@ static int err(int out, const char *legend)
 }
 #endif /* HAVE_SYS_TIMEPPS_H */
 
-void ppscheck(char *device)
+void ppscheck(const char *device)
 {
 #ifndef HAVE_SYS_TIMEPPS_H
 	(void)device;
@@ -73,14 +75,14 @@ void ppscheck(char *device)
 	pps_params_t pp;
 	pps_handle_t ph = 0;    /* 0 to prevent spurious uninialized warning */
 	int i, mode;
-	u_int olda = 0, oldc = 0;
+	unsigned int olda = 0, oldc = 0;
 	struct timespec to;
 
 	if (device == NULL)
 		device = "/dev/cuaa1";
 	setbuf(stdout, 0);
 	fd = open(device, O_RDONLY);
-	if (fd < 0) 
+	if (fd < 0)
 		err(1, device);
 	i = time_pps_create(fd, &ph);
 	if (i < 0)
@@ -90,11 +92,18 @@ void ppscheck(char *device)
 	if (i < 0)
 		err(1, "time_pps_getcap");
 
+        memset(&pp, 0, sizeof(pp));
 	/* pp.mode = PPS_CAPTUREASSERT | PPS_ECHOASSERT; */
 	pp.mode = PPS_CAPTUREBOTH;
 	/* pp.mode = PPS_CAPTUREASSERT; */
 
-	/* coverity[uninit_use_in_call] */
+#ifdef PPS_API_VERS
+        pp.api_version = PPS_API_VERS;
+#else
+        /* FreeBSD, NetBSD do not publicly define PPS_ABI_VERS, assume 1 */
+        pp.api_version = 1;
+#endif
+
 	i = time_pps_setparams(ph, &pp);
 	if (i < 0)
 		err(1, "time_pps_setparams");
@@ -107,7 +116,9 @@ void ppscheck(char *device)
 			err(1, "time_pps_fetch");
 		if (olda == pi.assert_sequence &&
 		    oldc == pi.clear_sequence) {
-			usleep(10000);
+			/* used to be usleep(10000) - 0.1 sec */
+			const struct timespec tenth = {0, 100000};
+			nanosleep(&tenth, NULL);
 			continue;
 		}
 
@@ -117,6 +128,7 @@ void ppscheck(char *device)
 		oldc = pi.clear_sequence;
 	}
 #endif /* HAVE_SYS_TIMEPPS_H */
+        /* either way, never returns */
 }
 
 /* end */
